@@ -52,16 +52,16 @@ class StoredEntity(Entity):
         self.root = self.obj.getRoot()
 
     @_init_obj_wrapper
-    def put_stream(self, stream_id, bytestream):
+    def put_stream(self, stream_id, bytestream, buffer_size=1024*8):
         # TODO: automatically update the manifest
-        self.obj.add_part(part_id, bytestream)
+        self.obj.add_part(stream_id, bytestream, buffer_size)
         if self.queue:
             self.log('w','stream', stream_id=stream_id)
 
     @_init_obj_wrapper
     def get_stream(self, stream_id):
         # TODO: automatically update the manifest
-        stream = self.obj.get_part(part_id, stream=True)
+        stream = self.obj.get_part(stream_id, stream=True)
         if self.queue:
             self.log('r','stream', stream_id=stream_id)
         return stream
