@@ -123,7 +123,11 @@ class FileMultiEntityFactory(object):
         pass
     
     def get_id(self, id, store):
-        pass
+        store_name = self._sanitise(store)
+        if not store_name in self.stores:
+            raise NotAValidStoreName()
+        else:
+            return self.stores[store_name].get_id(id)
     
 
 class FileEntityFactory(object):
