@@ -78,8 +78,8 @@ class FileStorageObject(object):
         """RDFObject for this object"""
         return self.fs._get_rdfobject(self.id, u'ROOT')
 
-    def add_part(self, partid, bytestream):
-        return self.fs._put_part(self.id, partid, bytestream)
+    def add_part(self, partid, bytestream, buffer_size):
+        return self.fs._put_part(self.id, partid, bytestream, buffer_size)
 
     def get_part(self, partid, stream=False):
         return self.fs._get_part(self.id, partid, stream)
@@ -221,7 +221,7 @@ class FileStorageClient(object):
         f.close()
         return version_no
 
-    def _put_part(self, id, part_id, bytestream):
+    def _put_part(self, id, part_id, bytestream, buffer_size):
         dirpath = os.path.join(self._id_to_dirpath(id), "%s" % (part_id))
         if not os.path.exists(dirpath):
             os.mkdir(dirpath)
@@ -231,7 +231,8 @@ class FileStorageClient(object):
         try:
             # Stream file-like objects in with buffered reads
             if hasattr(bytestream, 'read'):
-                buffer_size = 1024 * 8
+                if not buffer_size or buffer_size<1024:
+                    buffer_size = 1024 * 8
                 chunk = bytestream.read(buffer_size)
                 while chunk:
                     f.write(chunk)
